.. _citation:

Acknowledging and Citing
========================

.. |version_to_cite| replace:: 2024.10.0
.. |doi_hyperlink| replace:: https://doi.org/10.5281/zenodo.14010450
.. |citation_year| replace:: 2024

.. These substitutions are automatically updated by the GitHub Action
   to mint a release.

If you use PlasmaPy for a project that results in a publication,
please cite the |Zenodo| record for the specific version of PlasmaPy
used in your project. Citing a software package promotes scientific
reproducibility, gives credit to its developers, and highlights the
importance of software as a vital research product. 📝

Version |version_to_cite| of PlasmaPy may be cited with the following
reference:

   PlasmaPy Community et al. (|citation_year|). *PlasmaPy*, version
   |version_to_cite|, Zenodo, |doi_hyperlink|

This reference may be made, for example, by adding the following line to
the methods or acknowledgments section of a paper.

   This research made use of PlasmaPy version |version_to_cite|, a
   community-developed open source Python package for plasma research
   and education (PlasmaPy Community et al. |citation_year|).

We encourage authors to acknowledge the packages that PlasmaPy depends
on, such as `Astropy <https://www.astropy.org/acknowledging.html>`__,
`NumPy <https://numpy.org/citing-numpy>`__, and
`SciPy <https://scipy.org/citing-scipy>`__.

.. important::

   If you use a function that implements a technique originally from a
   research article referenced in its documentation, please also cite
   that research article.

.. caution::

   A development version of PlasmaPy should not be cited or used in
   published work.

.. tip::

   A paper written using `AASTeX <https://journals.aas.org/aastexguide>`__
   should use the ``\software{PlasmaPy}`` command to cite
   PlasmaPy. If the author instructions for a journal do not describe
   how to cite software, please follow the instructions on how to cite
   a dataset.

.. note::

   All public releases of PlasmaPy are openly archived in the `PlasmaPy
   Community <https://zenodo.org/communities/plasmapy/records>`__ on |Zenodo|.
